import click
from .core import FeastSchema

@click.group()
def cli():
    pass

@cli.command()
@click.argument("path", type=click.STRING, required=False)
@click.argument("skip_meta", type=click.BOOL, required=False)
@click.argument("feature_table", type=click.STRING, required=False)
def show(path: str = ".", skip_meta: bool = False, feature_table: str = None):
    if feature_table:
        FeastSchema(path).show_table_schema(feature_table,skip_meta)
    else:
        FeastSchema(path).show_schema(skip_meta)

if __name__ == "__main__":
    cli()





# encoding: utf-8
import sys

from setuptools import setup


def read_description():
    with open('README.md', 'r') as f:
        return f.read()


NAME = "feast-schema"
DESCRIPTION = "Feast schema inspect library"
URL = "https://github.com/qooba/feast-schema"
AUTHOR = "Kuba Sołtys"
REQUIRES_PYTHON = ">=3.7.0"
REQUIRED = [
    "feast",
    "json2html",
    "ipython",
    "Click"
]
REQUIRED_DEV = [
    "pytest",
    "requests",
    "pytest-cov>=2.10.1"
]

setup(
    name=NAME,
    version='0.0.1',
    url=URL,
    license='MIT',
    author=AUTHOR,
    author_email='dev@qooba.net',
    description=DESCRIPTION,
    long_description=read_description(),
    long_description_content_type="text/markdown",
    packages=['feast_schema'],
    python_requires=REQUIRES_PYTHON,
    install_requires=REQUIRED,
    extras_require={
        "dev": REQUIRED_DEV,
    },
    include_package_data=True,
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
    ],
    entry_points={"console_scripts": ["feast-schema=feast_schema.cli:cli"]},

)



from feast import FeatureStore
from IPython.core.display import display, HTML
import json
from json2html import *
import warnings
warnings.filterwarnings('ignore')

class FeastSchema:
    def __init__(self, repo_path: str):
        self.store = FeatureStore(repo_path=repo_path)

    def show_schema(self, skip_meta: bool= False):
        feast_schema=self.__project_show_schema(skip_meta)
        display(HTML(json2html.convert(json = feast_schema)))

    def show_table_schema(self, table: str, skip_meta: bool= False):
        feasture_tables_dictionary=self.__project_show_schema(skip_meta)
        display(HTML(json2html.convert(json = {table:feasture_tables_dictionary[table]})))

    def __project_show_schema(self, skip_meta: bool= False):
        entities_dictionary={}
        feast_entities=self.store.list_entities()
        for entity in feast_entities:
            entity_dictionary=entity.to_dict()
            entity_spec=entity_dictionary['spec']
            entities_dictionary[entity_spec['name']]=entity_spec

        feasture_tables_dictionary={}
        feast_feature_tables=self.store.list_feature_views()
        for feature_table in feast_feature_tables:
            feature_table_dict=json.loads(str(feature_table))
            feature_table_spec=feature_table_dict['spec']
            feature_table_name=feature_table_spec['name']
            feature_table_spec.pop('name',None)
            if 'entities' in feature_table_spec:
                feature_table_entities=[]
                for entity in feature_table_spec['entities']:
                    feature_table_entities.append(entities_dictionary[entity])
                feature_table_spec['entities']=feature_table_entities

            if not skip_meta:
                feature_table_spec['meta']=feature_table_dict['meta']
            else:
                feature_table_spec.pop('input',None)
                feature_table_spec.pop('ttl',None)
                feature_table_spec.pop('online',None)

            feasture_tables_dictionary[feature_table_name]=feature_table_spec

        return feasture_tables_dictionary
